==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/th_TH.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ปฏิทิน",
    "Individual" : "ของแต่ละบุคคล",
    "Group" : "กลุ่ม",
    "Resource" : "ทรัพยากร",
    "Room" : "ห้อง",
    "Unknown" : "ไม่ทราบ",
    "Required" : "ที่จำเป็น",
    "Optional" : "ตัวเลือก",
    "Does not attend" : "ไม่ได้เข้าร่วม",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "คุณอยู่ในเขตเวลาที่ไม่รู้จัก ({tz}), กำลงกลับไปสู่ UTC",
    "Please create a calendar first." : "กรุณาสร้างปฏิทินก่อน",
    "New event" : "เหตุการณ์ใหม่",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Reminders" : "การแจ้งเตือน",
    "Repeating" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Please add a title!" : "กรุณาเพิ่มหัวข้อ!",
    "Please select a calendar!" : "กรุณาเลือกปฏิทิน!",
    "Global" : "ทั่วไป",
    "None" : "ไม่มี",
    "Every day" : "ทุกวัน",
    "Every week" : "ทุกสัปดาห์",
    "Every month" : "ทุกเดือน",
    "Every year" : "ทุกปี",
    "never" : "ไม่ต้องเลย",
    "after" : "หลัง",
    "At time of event" : "ในช่วงเวลาของเหตุการณ์",
    "5 minutes before" : "5 นาทีก่อนหน้านั้น",
    "10 minutes before" : "10 นาทีก่อนหน้านั้น",
    "15 minutes before" : "15 นาทีก่อนหน้านั้น",
    "30 minutes before" : "30 นาทีก่อนหน้านั้น",
    "1 hour before" : "1 ชั่วโมงก่อนหน้านั้น",
    "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
    "Custom" : "กำหนดเอง",
    "Audio" : "เสียง",
    "E Mail" : "อีเมล",
    "Pop up" : "ป๊อปอัพ",
    "sec" : "วินาที",
    "min" : "นาที",
    "hours" : "ชั่วโมง",
    "days" : "วัน",
    "week" : "สัปดาห์",
    "before" : "ก่อน",
    "start" : "เริ่ม",
    "end" : "จบ",
    "Editing reminders of unknown type not supported." : "แจ้งเตือนการแก้ไขที่ไม่รู้จัก ไม่ได้รับการสนับสนุน",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Successfully imported" : "นำเข้าสำเร็จ",
    "Partially imported, 1 failure" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว 1 ",
    "Partially imported, {n} failures" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว {n}",
    "Audio alarm" : "เสียงแจ้งเตือน",
    "Pop-up" : "ป๊อปอัพ",
    "E-Mail" : "อีเมล",
    "{type} {time} before the event starts" : "{type} {time} ก่อนที่เหตุการณ์จะเริ่มต้น",
    "{type} {time} before the event ends" : "{type} {time} ก่อนที่เหตุการณ์จะจบลง",
    "{type} {time} after the event starts" : "{type} {time} หลังจากที่เริ่มต้นเหตุการณ์",
    "{type} {time} after the event ends" : "{type} {time} หลังจากที่เหตุการณ์จบลง",
    "{type} at the event's start" : "{type} ในช่วงที่เหตุการณ์เริ่มต้น",
    "{type} at the event's end" : "{type} ในช่วงที่เหตุการณ์จบลง",
    "{type} at {time}" : "{type} ตอน {time}",
    "{calendar} shared by {owner}" : "{calendar} ถูกแชร์โดย {owner}",
    "Title of the Event" : "ชื่อของกิจกรรม",
    "starts" : "เริ่ม",
    "ends" : "จบ",
    "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
    "Delete" : "ลบ",
    "Cancel" : "ยกเลิก",
    "More ..." : "เพิ่มเติม ...",
    "Create" : "สร้าง",
    "Update" : "อัพเดท",
    "Close" : "ปิด",
    "Location" : "ตำแหน่งที่อยู่",
    "Description" : "รายละเอียด",
    "Export" : "ส่งออก",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "เนื่องจากข้อผิดพลาดจากต้นทาง ปัจจุบันปฏิทินยังไม่ให้การสนับสนุนสำหรับคุณลักษณะ asset pipeline",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "กรุณาติดต่อผู้ดูแลระบบของคุณและขอให้ปิดการใช้งานการตั้งค่าตัวเลือก \"asset-pipeline.enabled\"",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Today" : "วันนี้",
    "Share Calendar" : "เปิดแชร์ปฏิทิน",
    "More" : "เพิ่มเติม",
    "Edit" : "แก้ไข",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "group" : "กลุ่มผู้ใช้งาน",
    "New Calendar" : "สร้างปฏิทินใหม่",
    "Subscriptions" : "สมัครสมาชิก",
    "New Subscription" : "สมัครสมาชิกใหม่",
    "Url" : "Url",
    "Edit event" : "แก้ไขกิจกรรม",
    "Delete Event" : "ลบเหตุการณ์",
    "Save Event" : "บันทึกเหตุการณ์",
    "Time" : "เวลา",
    "Type" : "ประเภท",
    "Relative" : "เครื่องญาติ",
    "Absolute" : "สมบูรณ์",
    "Repeat" : "ทำซ้ำ",
    "times every" : "ทุกครั้ง",
    "Add" : "เพิ่ม",
    "E-Mail address of attendee" : "ที่อยู่อีเมลของผู้เข้าร่วมประชุม",
    "Please add your email address in the personal settings in order to add attendees." : "กรุณาเพิ่มที่อยู่อีเมลของคุณในการตั้งค่าส่วนบุคคลเพื่อเพิ่มผู้เข้าร่วมประชุม",
    "from" : "จาก",
    "to" : "ถึง",
    "This event's repeating rule is not supported yet." : "กฎการทำซ้ำของเหตุการณ์นี้ยังไม่ได้รับการสนับสนุน",
    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการอัพเดท",
    "Reset repeating rule" : "รีเซ็ตกฎการทำซ้ำ",
    "Repeat every ..." : "ทำซ้ำตลอด ...",
    "end repeat ..." : "ยกเลิกการทำซ้ำ ...",
    "times" : "ครั้ง",
    "Import Calendars" : "นำเข้าปฏิทิน",
    "Import canceled" : "การนำเข้าถูกยกเลิก",
    "Analyzing calendar" : "วิเคราะห์ปฏิทิน",
    "The file contains objects incompatible with the selected calendar" : "ไฟล์ประกอบด้วยวัตถุเข้ากันไม่ได้กับปฏิทินที่เลือก",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Import scheduled" : "นำเข้าตารางเวลาตามที่กำหนดไว้",
    "Settings" : "ตั้งค่า",
    "Import calendar" : "นำเข้าปฏิทิน",
    "No Calendars selected for import" : "ไม่มีปฏิทินที่เลือกนำเข้า",
    "Primary CalDAV address" : "ที่อยู่ CalDAV หลัก",
    "iOS/OS X CalDAV address" : "ที่อยู่ CalDAV ของ iOS/OS X"
},
"nplurals=1; plural=0;");

==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/th_TH.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ปฏิทิน",
    "Individual" : "ของแต่ละบุคคล",
    "Group" : "กลุ่ม",
    "Resource" : "ทรัพยากร",
    "Room" : "ห้อง",
    "Unknown" : "ไม่ทราบ",
    "Required" : "ที่จำเป็น",
    "Optional" : "ตัวเลือก",
    "Does not attend" : "ไม่ได้เข้าร่วม",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "คุณอยู่ในเขตเวลาที่ไม่รู้จัก ({tz}), กำลงกลับไปสู่ UTC",
    "Please create a calendar first." : "กรุณาสร้างปฏิทินก่อน",
    "New event" : "เหตุการณ์ใหม่",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Reminders" : "การแจ้งเตือน",
    "Repeating" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Confirmed" : "ได้รับการยืนยันแล้ว",
    "Tentative" : "ชั่วคราว",
    "Cancelled" : "ยกเลิกแล้ว",
    "Please add a title!" : "กรุณาเพิ่มหัวข้อ!",
    "Please select a calendar!" : "กรุณาเลือกปฏิทิน!",
    "Global" : "ทั่วไป",
    "None" : "ไม่มี",
    "Every day" : "ทุกวัน",
    "Every week" : "ทุกสัปดาห์",
    "Every month" : "ทุกเดือน",
    "Every year" : "ทุกปี",
    "never" : "ไม่ต้องเลย",
    "after" : "หลัง",
    "At time of event" : "ในช่วงเวลาของเหตุการณ์",
    "5 minutes before" : "5 นาทีก่อนหน้านั้น",
    "10 minutes before" : "10 นาทีก่อนหน้านั้น",
    "15 minutes before" : "15 นาทีก่อนหน้านั้น",
    "30 minutes before" : "30 นาทีก่อนหน้านั้น",
    "1 hour before" : "1 ชั่วโมงก่อนหน้านั้น",
    "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
    "Custom" : "กำหนดเอง",
    "Audio" : "เสียง",
    "E Mail" : "อีเมล",
    "Pop up" : "ป๊อปอัพ",
    "sec" : "วินาที",
    "min" : "นาที",
    "hours" : "ชั่วโมง",
    "days" : "วัน",
    "week" : "สัปดาห์",
    "before" : "ก่อน",
    "start" : "เริ่ม",
    "end" : "จบ",
    "Editing reminders of unknown type not supported." : "แจ้งเตือนการแก้ไขที่ไม่รู้จัก ไม่ได้รับการสนับสนุน",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Successfully imported" : "นำเข้าสำเร็จ",
    "Partially imported, 1 failure" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว 1 ",
    "Partially imported, {n} failures" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว {n}",
    "Audio alarm" : "เสียงแจ้งเตือน",
    "Pop-up" : "ป๊อปอัพ",
    "E-Mail" : "อีเมล",
    "{type} {time} before the event starts" : "{type} {time} ก่อนที่เหตุการณ์จะเริ่มต้น",
    "{type} {time} before the event ends" : "{type} {time} ก่อนที่เหตุการณ์จะจบลง",
    "{type} {time} after the event starts" : "{type} {time} หลังจากที่เริ่มต้นเหตุการณ์",
    "{type} {time} after the event ends" : "{type} {time} หลังจากที่เหตุการณ์จบลง",
    "{type} at the event's start" : "{type} ในช่วงที่เหตุการณ์เริ่มต้น",
    "{type} at the event's end" : "{type} ในช่วงที่เหตุการณ์จบลง",
    "{type} at {time}" : "{type} ตอน {time}",
    "{calendar} shared by {owner}" : "{calendar} ถูกแชร์โดย {owner}",
    "Title of the Event" : "ชื่อของกิจกรรม",
    "starts" : "เริ่ม",
    "ends" : "จบ",
    "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
    "Delete" : "ลบ",
    "Cancel" : "ยกเลิก",
    "More ..." : "เพิ่มเติม ...",
    "Create" : "สร้าง",
    "Update" : "อัพเดท",
    "Close" : "ปิด",
    "Location" : "ตำแหน่งที่อยู่",
    "Description" : "รายละเอียด",
    "Event status" : "สถานะเหตุการณ์",
    "Visibility when sharing" : "แสดงผลเมื่อมีการแชร์",
    "Export" : "ส่งออก",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "เนื่องจากข้อผิดพลาดจากต้นทาง ปัจจุบันปฏิทินยังไม่ให้การสนับสนุนสำหรับคุณลักษณะ asset pipeline",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "กรุณาติดต่อผู้ดูแลระบบของคุณและขอให้ปิดการใช้งานการตั้งค่าตัวเลือก \"asset-pipeline.enabled\"",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Today" : "วันนี้",
    "Some events in this calendar are broken. Please check the JS console for more info." : "เหตุการณ์บางอย่างในปฏิทินนี้เสียหาย กรุณาตรวจสอบคอนโซล JS สำหรับข้อมูลเพิ่มเติม",
    "Share Calendar" : "เปิดแชร์ปฏิทิน",
    "Shared" : "แชร์แล้ว",
    "More" : "เพิ่มเติม",
    "Edit" : "แก้ไข",
    "Link" : "ลิงค์",
    "Download" : "ดาวน์โหลด",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "group" : "กลุ่มผู้ใช้งาน",
    "New Calendar" : "สร้างปฏิทินใหม่",
    "Subscriptions" : "สมัครสมาชิก",
    "New Subscription" : "สมัครสมาชิกใหม่",
    "Url" : "Url",
    "Edit event" : "แก้ไขกิจกรรม",
    "Delete Event" : "ลบเหตุการณ์",
    "Save Event" : "บันทึกเหตุการณ์",
    "Time" : "เวลา",
    "Type" : "ประเภท",
    "Relative" : "เครื่องญาติ",
    "Absolute" : "สมบูรณ์",
    "Repeat" : "ทำซ้ำ",
    "times every" : "ทุกครั้ง",
    "Add" : "เพิ่ม",
    "E-Mail address of attendee" : "ที่อยู่อีเมลของผู้เข้าร่วมประชุม",
    "Please add your email address in the personal settings in order to add attendees." : "กรุณาเพิ่มที่อยู่อีเมลของคุณในการตั้งค่าส่วนบุคคลเพื่อเพิ่มผู้เข้าร่วมประชุม",
    "from" : "จาก",
    "to" : "ถึง",
    "This event's repeating rule is not supported yet." : "กฎการทำซ้ำของเหตุการณ์นี้ยังไม่ได้รับการสนับสนุน",
    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการอัพเดท",
    "Reset repeating rule" : "รีเซ็ตกฎการทำซ้ำ",
    "Repeat every ..." : "ทำซ้ำตลอด ...",
    "end repeat ..." : "ยกเลิกการทำซ้ำ ...",
    "times" : "ครั้ง",
    "Import Calendars" : "นำเข้าปฏิทิน",
    "Import canceled" : "การนำเข้าถูกยกเลิก",
    "Analyzing calendar" : "วิเคราะห์ปฏิทิน",
    "The file contains objects incompatible with the selected calendar" : "ไฟล์ประกอบด้วยวัตถุเข้ากันไม่ได้กับปฏิทินที่เลือก",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Import scheduled" : "นำเข้าตารางเวลาตามที่กำหนดไว้",
    "Settings" : "ตั้งค่า",
    "Import calendar" : "นำเข้าปฏิทิน",
    "No Calendars selected for import" : "ไม่มีปฏิทินที่เลือกนำเข้า",
    "Primary CalDAV address" : "ที่อยู่ CalDAV หลัก",
    "iOS/OS X CalDAV address" : "ที่อยู่ CalDAV ของ iOS/OS X"
},
"nplurals=1; plural=0;");
